% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/paws.R
\name{support}
\alias{support}
\title{AWS Support}
\usage{
support(config = list())
}
\arguments{
\item{config}{Optional configuration of credentials, endpoint, and/or region.
\itemize{
\item{\strong{access_key_id}:} {AWS access key ID}
\item{\strong{secret_access_key}:} {AWS secret access key}
\item{\strong{session_token}:} {AWS temporary session token}
\item{\strong{profile}:} {The name of a profile to use. If not given, then the default profile is used.}
\item{\strong{anonymous}:} {Set anonymous credentials.}
\item{\strong{endpoint}:} {The complete URL to use for the constructed client.}
\item{\strong{region}:} {The AWS Region used in instantiating the client.}
\item{\strong{close_connection}:} {Immediately close all HTTP connections.}
\item{\strong{timeout}:} {The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
\item{\strong{s3_force_path_style}:} {Set this to \code{true} to force the request to use path-style addressing, i.e., \verb{http://s3.amazonaws.com/BUCKET/KEY}.}
}}
}
\value{
A client for the service. You can call the service's operations using
syntax like \code{svc$operation(...)}, where \code{svc} is the name you've assigned
to the client. The available operations are listed in the
Operations section.
}
\description{
Amazon Web Services Support

The \emph{Amazon Web Services Support API Reference} is intended for
programmers who need detailed information about the Amazon Web Services
Support operations and data types. You can use the API to manage your
support cases programmatically. The Amazon Web Services Support API uses
HTTP methods that return results in JSON format.
\itemize{
\item You must have a Business, Enterprise On-Ramp, or Enterprise Support
plan to use the Amazon Web Services Support API.
\item If you call the Amazon Web Services Support API from an account that
does not have a Business, Enterprise On-Ramp, or Enterprise Support
plan, the \code{SubscriptionRequiredException} error message appears. For
information about changing your support plan, see \href{https://aws.amazon.com/premiumsupport/}{Amazon Web Services Support}.
}

The Amazon Web Services Support service also exposes a set of \href{https://aws.amazon.com/premiumsupport/technology/trusted-advisor/}{Trusted Advisor}
features. You can retrieve a list of checks and their descriptions, get
check results, specify checks to refresh, and get the refresh status of
checks.

The following list describes the Amazon Web Services Support case
management operations:
\itemize{
\item Service names, issue categories, and available severity levels - The
\code{describe_services} and
\code{describe_severity_levels}
operations return Amazon Web Services service names, service codes,
service categories, and problem severity levels. You use these
values when you call the \code{create_case}
operation.
\item Case creation, case details, and case resolution - The
\code{create_case},
\code{describe_cases},
\code{describe_attachment}, and
\code{resolve_case} operations create Amazon Web
Services Support cases, retrieve information about cases, and
resolve cases.
\item Case communication - The
\code{describe_communications},
\code{add_communication_to_case},
and \code{add_attachments_to_set}
operations retrieve and add communications and attachments to Amazon
Web Services Support cases.
}

The following list describes the operations available from the Amazon
Web Services Support service for Trusted Advisor:
\itemize{
\item \code{describe_trusted_advisor_checks}
returns the list of checks that run against your Amazon Web Services
resources.
\item Using the \code{checkId} for a specific check returned by
\code{describe_trusted_advisor_checks},
you can call
\code{describe_trusted_advisor_check_result}
to obtain the results for the check that you specified.
\item \code{describe_trusted_advisor_check_summaries}
returns summarized results for one or more Trusted Advisor checks.
\item \code{refresh_trusted_advisor_check}
requests that Trusted Advisor rerun a specified check.
\item \code{describe_trusted_advisor_check_refresh_statuses}
reports the refresh status of one or more checks.
}

For authentication of requests, Amazon Web Services Support uses
\href{https://docs.aws.amazon.com/general/latest/gr/signing-aws-api-requests.html}{Signature Version 4 Signing Process}.

See \href{https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html}{About the Amazon Web Services Support API}
in the \emph{Amazon Web Services Support User Guide} for information about
how to use this service to create and manage your support cases, and how
to call Trusted Advisor for results of checks on your resources.
}
\section{Service syntax}{


\if{html}{\out{<div class="sourceCode">}}\preformatted{svc <- support(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical"
  )
)
}\if{html}{\out{</div>}}
}

\section{Operations}{

\tabular{ll}{
\link[paws.management:support_add_attachments_to_set]{add_attachments_to_set} \tab Adds one or more attachments to an attachment set\cr
\link[paws.management:support_add_communication_to_case]{add_communication_to_case} \tab Adds additional customer communication to an Amazon Web Services Support case\cr
\link[paws.management:support_create_case]{create_case} \tab Creates a case in the Amazon Web Services Support Center\cr
\link[paws.management:support_describe_attachment]{describe_attachment} \tab Returns the attachment that has the specified ID\cr
\link[paws.management:support_describe_cases]{describe_cases} \tab Returns a list of cases that you specify by passing one or more case IDs\cr
\link[paws.management:support_describe_communications]{describe_communications} \tab Returns communications and attachments for one or more support cases\cr
\link[paws.management:support_describe_services]{describe_services} \tab Returns the current list of Amazon Web Services services and a list of service categories for each service\cr
\link[paws.management:support_describe_severity_levels]{describe_severity_levels} \tab Returns the list of severity levels that you can assign to a support case\cr
\link[paws.management:support_describe_trusted_advisor_check_refresh_statuses]{describe_trusted_advisor_check_refresh_statuses} \tab Returns the refresh status of the Trusted Advisor checks that have the specified check IDs\cr
\link[paws.management:support_describe_trusted_advisor_check_result]{describe_trusted_advisor_check_result} \tab Returns the results of the Trusted Advisor check that has the specified check ID\cr
\link[paws.management:support_describe_trusted_advisor_checks]{describe_trusted_advisor_checks} \tab Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata\cr
\link[paws.management:support_describe_trusted_advisor_check_summaries]{describe_trusted_advisor_check_summaries} \tab Returns the results for the Trusted Advisor check summaries for the check IDs that you specified\cr
\link[paws.management:support_refresh_trusted_advisor_check]{refresh_trusted_advisor_check} \tab Refreshes the Trusted Advisor check that you specify using the check ID\cr
\link[paws.management:support_resolve_case]{resolve_case} \tab Resolves a support case
}
}

\examples{
\dontrun{
svc <- support()
svc$add_attachments_to_set(
  Foo = 123
)
}

}
